/*
 * Copyright (c) 2023-Present Jonathan MASSUCHETTI <jonathan.massuchetti@dappit.fr>.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { retry } from 'ts-retry-promise';
import { isPartialKeyspace } from '@cbjsdev/shared';
import { getQuerySearchIndexes } from '../services/index.js';
import { waitOptionsModerate } from './options.js';
export async function waitForSearchIndex(apiConfig, indexName, ...args) {
    const [keyspace, options] = isPartialKeyspace(args[0])
        ? args
        : [undefined, args[0]];
    const resolvedOptions = {
        ...waitOptionsModerate,
        ...options,
    };
    const { expectMissing, awaitMutations } = resolvedOptions;
    return await retry(async () => {
        const indexes = await getQuerySearchIndexes(apiConfig, {
            ...keyspace,
            index: indexName,
        });
        const index = indexes[0];
        if (!index && !expectMissing)
            throw new Error('Search index is not visible yet');
        if (index && expectMissing)
            throw new Error('Search index still exists');
        if (!awaitMutations || expectMissing) {
            return;
        }
        if (index?.state !== 'online') {
            throw new Error('Search index still being built');
        }
    }, resolvedOptions);
}
//# sourceMappingURL=waitForSearchIndex.js.map